# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [1.0.8] - 2023-02-20
### Changed
- Add logging parameters to the constructor of the class `BaseAgent`
- Replace Pipfile with Poetry

## [1.0.6] - 2022-02-01
### Changed
- Add keyworded variable-length argument list to the method `start`

## [1.0.5] - 2021-06-16
### Added
- Add debugging information

## [1.0.3] - 2021-06-14
### Added
- Add a default idle time between two consecutive successful runs

## [1.0.2] - 2021-06-07
### Changed
- Declare base classes as abstract

## [1.0.0] - 2021-06-06
### Added
- Initial import
